@@ -552,7 +552,8 @@ class AccountSerializer(serializers.Serializer):
     "011100_3" for "Dienstleistung / Handwerk / Baugewerbe / Ladenbau / Maßmöbel"
 
     """
-    branch_codes = serializers.ListField(child=serializers.CharField(max_length=16, required=True), required=True)
+    branch_codes = serializers.ListField(
+        child=serializers.CharField(max_length=16, required=True), required=True, allow_empty=False)
 
     """
     generic comment on the customer
@@ -933,7 +934,8 @@ class OrderLineGoogleAdsBasicSerializer(serializers.Serializer):
     """
     which cities/regions should the ad be targeted on?
     """
-    regions = serializers.ListField(child=serializers.CharField(max_length=100, required=True), required=True)
+    regions = serializers.ListField(
+        child=serializers.CharField(max_length=100, required=True), required=True, allow_empty=False)
 
     """
     customer preferred keywords to be found on with his campaign
@@ -957,6 +959,11 @@ class OrderLineGoogleAdsBasicSerializer(serializers.Serializer):
     """
     target_page_type = serializers.ChoiceField(choices=GOOGLE_ADS_LANDING_PAGE_CHOICES, required=False)
 
+    """
+    url of the ads target website if CUSTOMER_WEBSITE is chosen in target_page_type
+    """
+    target_url = serializers.URLField(allow_blank=True, required=False)
+
 
 class OrderLineGoogleAdsPremiumSerializer(serializers.Serializer):
     """
@@ -1021,6 +1028,11 @@ class OrderLineGoogleAdsPremiumSerializer(serializers.Serializer):
     """
     target_page_type = serializers.ChoiceField(choices=GOOGLE_ADS_LANDING_PAGE_CHOICES, required=False)
 
+    """
+    url of the ads target website if CUSTOMER_WEBSITE is chosen in target_page_type
+    """
+    target_url = serializers.URLField(allow_blank=True, required=False)
+
     """
     specifies if campaign will be tracked or not.
     This is true in case if customer has campaign tracking booked for Stroer Website.
@@ -1665,13 +1677,14 @@ class OrderLineSeoSerializer(serializers.Serializer):
 
     """
     topics = serializers.ListField(
-        child=serializers.CharField(max_length=100, required=True), required=True)
+        child=serializers.CharField(max_length=100, required=True), required=True, allow_empty=False)
 
     """
     regions to optimize for
 
     """
-    regions = serializers.ListField(child=serializers.CharField(max_length=100, required=True), required=True)
+    regions = serializers.ListField(
+        child=serializers.CharField(max_length=100, required=True), required=True, allow_empty=False)
 
     """
     main focus of the seo optimization, which of the customers products/services is the most important?
@@ -1735,7 +1748,7 @@ class OrderLineWebsiteSerializer(serializers.Serializer):
     count of addtionally booked subpages
 
     """
-    additional_subpages = serializers.IntegerField(required=True, min_value=0)
+    additional_subpages = serializers.IntegerField(required=True, min_value=0, max_value=60)
 
     """
     customer desired domain name
